This is the example of silicon calculation. The supercell is 2x2x2 of the
conventional unit cell. The qe (pw) calculation was made to obtain forces with
50 Ry, 2x2x2 k-point mesh for the supercell, PBE, and the lattice parameters in
Si.in. Silicon crystal is F-centre, so there is the transformation matrix from
the conventional unit cell to the primitive cell.

`phono3py_disp.yaml` is generated by

```
% phono3py --qe -d --dim 2 2 2 -c Si.in --pa auto
```

To create `fc3.hdf5` and `fc2.hdf5`,

```
% phono3py --sym-fc
```

Using 11x11x11 sampling mesh, lattice thermal conductivity is calculated by

```
% phono3py --mesh 11 11 11 --fc3 --fc2 --br
```

`kappa-m111111.hdf5` is written as the result. The lattice thermal conductivity
is calculated as 118.9 W/m-K at 300 K. This becomes, with 19x19x19 sampling
mesh, 129.9 W/m-K.

The .out files for supercells are found in `supercell_out.tar.lzma`. If phono3py
is properly installed, the following command should work.

```
% phono3py --cf3 supercell_out/disp-{00001..00111}/Si.out
```
